GWCelery
========

GWCelery is a simple and reliable package for annotating and orchestrating
LIGO/Virgo alerts, built from widely used open source components.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart
   configuration
   monitoring
   htcondor
   contributing
   design
   gwcelery

.. toctree::
   :maxdepth: 1

   Git repository <http://git.ligo.org/emfollow/gwcelery>
   changes
   license

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

GWCelery is open source and is licensed under the :doc:`GNU General Public
License v2 or later <license>`.
